TODO:

bwaaaa

I like these card-type templates:

- [ramanspy tutorials](https://ramanspy.readthedocs.io/en/latest/auto_tutorials/index.html)
- [cartopy gallery](https://scitools.org.uk/cartopy/docs/latest/gallery/index.html)
